{{/* vim: set filetype=mustache: */}}
{{/*
Expand the name of the chart.
*/}}
{{- define "stacklight.name" -}}
{{- default .Chart.Name .Values.nameOverride | trunc 63 | trimSuffix "-" -}}
{{- end -}}

{{/*
Create a default fully qualified app name.
We truncate at 63 chars because some Kubernetes name fields are limited to this (by the DNS naming spec).
If release name contains chart name it will be used as a full name.
*/}}
{{- define "stacklight.fullname" -}}
{{- if .Values.fullnameOverride -}}
{{- .Values.fullnameOverride | trunc 63 | trimSuffix "-" -}}
{{- else -}}
{{- $name := default .Chart.Name .Values.nameOverride -}}
{{- if contains $name .Release.Name -}}
{{- .Release.Name | trunc 63 | trimSuffix "-" -}}
{{- else -}}
{{- printf "%s-%s" .Release.Name $name | trunc 63 | trimSuffix "-" -}}
{{- end -}}
{{- end -}}
{{- end -}}

{{/*
Create chart name and version as used by the chart label.
*/}}
{{- define "stacklight.chart" -}}
{{- printf "%s-%s" .Chart.Name .Chart.Version | replace "+" "_" | trunc 63 | trimSuffix "-" -}}
{{- end -}}

{{/*
Common labels
*/}}
{{- define "stacklight.labels" -}}
app.kubernetes.io/name: {{ include "stacklight.name" . }}
helm.sh/chart: {{ include "stacklight.chart" . }}
app.kubernetes.io/instance: {{ .Release.Name }}
{{- if .Chart.AppVersion }}
app.kubernetes.io/version: {{ .Chart.AppVersion | quote }}
{{- end }}
app.kubernetes.io/managed-by: {{ .Release.Service }}
{{- end -}}

{{/*
Helm Controller high availability ConfigMap name for leader election lock
*/}}
{{- define "stacklight.helmControllerLeaderLock" -}}
stacklight-helm-controller-leader-election
{{- end -}}

{{/*
Resources section
*/}}
{{- define "stacklight.resources" -}}
{{- $resources := mergeOverwrite (index (index .inTplValues.resourcesPerClusterSize .service | default (dict .inTplValues.clusterSize dict)) .inTplValues.clusterSize) (index .inTplValues.resources .service) }}
{{ dict "resources" $resources | toYaml }}
{{- end -}}

{{- define "stacklight.nodeSelector" -}}
{{- $nodeSelector := dict }}
{{- $nodeSelector = mergeOverwrite $nodeSelector .inTplValues.nodeSelector.default (index .inTplValues.nodeSelector.component .service | default dict) }}
{{- if $nodeSelector }}
nodeSelector:
{{ toYaml $nodeSelector | indent 2 }}
{{- end }}
{{- end -}}

{{- define "stacklight.tolerations" -}}
{{ $tolerations := concat .inTplValues.tolerations.default (index .inTplValues.tolerations.component .service | default list ) | uniq }}
{{- if $tolerations }}
tolerations:
{{ toYaml $tolerations | indent 2 }}
{{- end }}
{{- end -}}

{{- define "stacklight.alertmanager.route" -}}
{{- with .match }}
match:
  {{- toYaml . | nindent 2 }}
{{- end }}
{{- with .match_re }}
match_re:
  {{- toYaml . | nindent 2 }}
{{- end }}
{{- with .routes }}
routes:
  {{- toYaml . | nindent 2 }}
{{- end }}
{{- end -}}

{{- define "stacklight.clusterId" -}}
{{- if not (empty .Values.clusterId) -}}
{{- printf "%s" .Values.clusterId -}}
{{- else if .Values.telemetry.telemeterServer.enabled -}}
{{- printf "%s" .Values.telemetry.telemeterServer.id -}}
{{- else if .Values.telemetry.telemeterClient.enabled -}}
{{- printf "%s" .Values.telemetry.telemeterClient.id -}}
{{- end -}}
{{- end -}}

{{- define "stacklight.commonChartParams" -}}
{{- $artifacts := .root.Files.Get "files/artifacts.yaml" | fromYaml }}
{{- $chartVersion := index (index $artifacts "chartsVersions") .chart }}
{{- $chart := index $chartVersion "chart" }}
{{- $version := index $chartVersion "version" }}
{{- dict "chart" $chart "version" $version "namespace" .root.Release.Namespace | toYaml }}
{{- end -}}

{{- define "stacklight.getImage" -}}
  {{- $artifacts := .root.Files.Get "files/artifacts.yaml" | fromYaml }}
  {{- $images := index $artifacts "dockerImagesVersions" }}
  {{- $image := index $images .image }}
  {{- $registry := .root.Values.global.dockerBaseUrl }}
  {{- $imgSplit := split ":" $image }}
  {{- $repo := list $registry $imgSplit._0 | join "/" }}
  {{- if .flat }}
    {{- list $registry $image | join "/" }}
  {{- else }}
    {{- dict "repository" $repo "tag" $imgSplit._1 | toYaml }}
  {{- end }}
{{- end -}}

{{- define "memUnitEnum" -}}
{{- dict "" 0 "k" 1 "m" 2 "g" 3 | toYaml }}
{{- end -}}

{{- define "normalizeMem" -}}
{{- $mem := index . "memory" | int64 }}
{{- if not (index . "hasI") }}
  {{- $unit := index . "unit" }}
  {{- $unitDict := include "memUnitEnum" . | fromYaml }}
  {{- range $_ := until (index $unitDict $unit | int) }}
    {{- $mem = mul $mem 1000 }}
    {{- $mem = div $mem 1024 }}
  {{- end }}
{{- end }}
{{- $mem }}
{{- end -}}

{{- define "memStringToMap" -}}
{{- $hasI := hasSuffix "i" . }}
{{- $mem := . | trimSuffix "i" | lower }}
{{- $unit := "" }}
{{- range $u := keys (omit (include "memUnitEnum" . | fromYaml) "") }}
  {{- if hasSuffix $u $mem }}
    {{- $unit = $u }}
  {{- end }}
{{- end }}
{{- $mem = $mem | trimSuffix $unit | int64 }}
{{- $memNorm := include "normalizeMem" (dict "memory" $mem "unit" $unit "hasI" $hasI) | int64 }}
{{- dict "memory" $memNorm "unit" $unit | toYaml }}
{{- end -}}

{{- define "memStringToMB" -}}
{{- $memMap := include "memStringToMap" . | fromYaml }}
{{- $mem := index $memMap "memory" }}
{{- $unit := index $memMap "unit" }}
{{- if eq $unit "g" }}
  {{- $mem = mul $mem 1024 }}
{{- end }}
{{- $mem }}
{{- end -}}

{{- define "stacklight.logLevel" -}}
{{- $key := index (index .root.Values.stacklightLogLevels "component" | default dict) .component | default (index .root.Values.stacklightLogLevels "default" | default "") -}}
{{- index .logLevels $key | default "" -}}
{{- end -}}
